Revert "wlan: Send auth resp if auth req is rx in connected state"

This reverts commit 27d662667c5b9d9bf8dec851fc649472a9b667b5

Change-Id: Iaa229e9bef65ff0b04262108fa614e3e39ce777d
CRs-Fixed: 848129
diff --git a/CORE/MAC/src/pe/lim/limProcessAuthFrame.c b/CORE/MAC/src/pe/lim/limProcessAuthFrame.c
index 2a7902b..09bb745 100644
--- a/CORE/MAC/src/pe/lim/limProcessAuthFrame.c
+++ b/CORE/MAC/src/pe/lim/limProcessAuthFrame.c
@@ -633,7 +633,8 @@
 
                 /* pStaDS != NULL and isConnected = 1 means the STA is already
                  * connected, But SAP received the Auth from that station.
                  * For non PMF connection send Auth response frame.
                  *
                  * For PMF connection the AP should not tear down or otherwise
                  * modify the state of the existing association until the
@@ -646,13 +647,14 @@
 #endif
                                           )
                 {
-                    authFrame.authAlgoNumber =
-                        pRxAuthFrameBody->authAlgoNumber;
-                    authFrame.authTransactionSeqNumber =
-                        pRxAuthFrameBody->authTransactionSeqNumber + 1;
-                    authFrame.authStatusCode = eSIR_MAC_SUCCESS_STATUS;
-                    limSendAuthMgmtFrame(pMac, &authFrame, pHdr->sa,
-                        LIM_NO_WEP_IN_FC, psessionEntry, eSIR_FALSE);
+                    limLog(pMac, LOGE,
+                            FL("STA is already connected but received auth frame"
+                                "Send the Deauth and lim Delete Station Context"
+                                "(staId: %d, assocId: %d) "),
+                            pStaDs->staIndex, assocId);
+                    limSendDeauthMgmtFrame(pMac, eSIR_MAC_UNSPEC_FAILURE_REASON,
+                            (tANI_U8 *) pHdr->sa, psessionEntry, FALSE);
+                    limTriggerSTAdeletion(pMac, pStaDs, psessionEntry);
                     return;
                 }
             }
@@ -710,13 +712,12 @@
 #endif
                        )
                     {
-                        authFrame.authAlgoNumber =
-                            pRxAuthFrameBody->authAlgoNumber;
-                        authFrame.authTransactionSeqNumber =
-                            pRxAuthFrameBody->authTransactionSeqNumber + 1;
-                        authFrame.authStatusCode = eSIR_MAC_SUCCESS_STATUS;
-                        limSendAuthMgmtFrame(pMac, &authFrame, pHdr->sa,
-                            LIM_NO_WEP_IN_FC, psessionEntry, eSIR_FALSE);
+                        PELOGE(limLog(pMac, LOGE, FL("lim Delete Station "
+                        "Context (staId: %d, assocId: %d) "),pStaDs->staIndex,
+                        assocId);)
+                        limSendDeauthMgmtFrame(pMac,
+                               eSIR_MAC_UNSPEC_FAILURE_REASON, (tANI_U8 *) pAuthNode->peerMacAddr, psessionEntry, FALSE);
+                        limTriggerSTAdeletion(pMac, pStaDs, psessionEntry);
                         return;
                     }
                 }
@@ -633,7 +633,8 @@
                 /* pStaDS != NULL and isConnected = 1 means the STA is already
                  * connected, But SAP received the Auth from that station.
-                 * For non PMF connection send Auth response frame.
+                 * For non PMF connection send Deauth frame as STA will retry
+                 * to connect back.
                  *
                  * For PMF connection the AP should not tear down or otherwise